@@ -1,14 +1,17 @@
 """
 Contains the initialization for the autoconfiguration package. It searches for the
-config files and initializes the instance of :class:`Config`.
+config files and initializes the instance of a config class.
 """
-
+import dataclasses
 import logging
 import os
-from typing import Tuple
+from typing import Tuple, Type
 
-from autoconfiguration.config import Config
-from autoconfiguration.exceptions.config_class_errors import ConfigNotInitializedError
+from autoconfiguration.create_config import create_config_instance
+from autoconfiguration.exceptions.config_class_errors import (
+    ConfigNotInitializedError,
+    ConfigClassIsNotDataclassError,
+)
 from autoconfiguration.exceptions.config_dir_errors import ConfigDirNotFoundError
 from autoconfiguration.exceptions.config_file_errors import NoConfigFilesFoundError
 
@@ -19,25 +22,37 @@ CONFIG_PREFIX = "config-"
 GLOBAL_CONFIG = f"config{CONFIG_EXTENSION}"
 
 
-def init(*args: str, config_dir: str = "config") -> Config:
+class _Constants:
+    pass
+
+
+def init(*args: str, config_class: Type, config_dir: str = "config"):
     """
-    Initializes the :class:`Config` class.
+    Initializes the passed config class with the values of the *.ini files.
 
     Searches for the passed configuration files (args) automatically inside
     config_dir. The global config (config.ini) is always loaded by default. The order
     of the passed files matters because the files can depend on each other. Files at
-    a higher index in the list can depend on files with lower indices. Values are
+    a higher indices in the list can depend on files with lower indices. Values are
     overwritten by files at a higher index.
 
     :param args: Environments that should be loaded. They should be inside config_dir.
+    :param config_class: The class that should be initialized with the values of the
+        *.ini files. This class and the types of its attributes have to be dataclasses.
     :param config_dir: Should be a path that is reachable from the directory where the
         application was executed. Default: config
-    :returns: The initialized :class:`Config` instance containing the values of the
+    :returns: The initialized config class instance containing the values of the
         config files
     """
-    if Config._instance:
+    if hasattr(_Constants, "config_instance") and _Constants.config_instance:
         LOG.debug("Config was already initialized. Returning existing instance.")
-        return Config()
+        return _Constants.config_instance
+
+    if not dataclasses.is_dataclass(config_class) or not all(
+        dataclasses.is_dataclass(field.type)
+        for field in dataclasses.fields(config_class)
+    ):
+        raise ConfigClassIsNotDataclassError()
 
     if not os.path.exists(config_dir):
         raise ConfigDirNotFoundError(config_dir)
@@ -47,19 +62,21 @@ def init(*args: str, config_dir: str = "config") -> Config:
     config_files = _validate_config_files(*args, config_dir=config_dir)
     LOG.info("The following config files were found: %s", config_files)
 
-    return Config(config_files)
+    instance = create_config_instance(config_class, config_files)
+    _Constants.config_instance = instance
+    return instance
 
 
 def get():
     """
-    Returns the initialized :class:`Config` instance.
+    Returns the initialized instance of the config class passed to init.
 
-    :returns: The initialized :class:`Config` instance
-    :raise ConfigNotInitializedError: If the :class:`Config` was not initialized
+    :returns: The initialized instance of the config class
+    :raise ConfigNotInitializedError: If the config class was not initialized
     """
-    if not Config._instance:
+    if not hasattr(_Constants, "config_instance") or not _Constants.config_instance:
         raise ConfigNotInitializedError()
-    return Config()
+    return _Constants.config_instance
 
 
 def _validate_config_files(*args: str, config_dir: str) -> Tuple[str, ...]:
@@ -99,4 +116,4 @@ def _get_correct_config_filename(filename: str):
 
 
 def _reset():
-    Config._instance = None
+    _Constants.config_instance = None
